/*
This file is part of LightDM-KDE.

Copyright 2012 David Edmundson <kde@davidedmundson.co.uk>
Copyright (C) 2021 Aleksei Nikiforov <darktemplar@basealt.ru>

LightDM-KDE is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

LightDM-KDE is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with LightDM-KDE.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GREETERWRAPPER_H
#define GREETERWRAPPER_H

#include <KSharedConfig>

#include <QLightDM/Greeter>

class GreeterWrapper: public QLightDM::Greeter
{
    Q_OBJECT

    Q_PROPERTY(QString lastLoggedInUser READ lastLoggedInUser CONSTANT)
    Q_PROPERTY(QString lastLoggedInSession READ lastLoggedInSession CONSTANT)
    Q_PROPERTY(QString guestLoginName READ guestLoginName CONSTANT)
    Q_PROPERTY(bool allowAutologin MEMBER m_allowAutologin)
    Q_PROPERTY(QString autologinSession READ autologinSessionHint)
    Q_PROPERTY(bool hideUsers READ hideUsersHint CONSTANT)
    Q_PROPERTY(bool showManualLogin READ showManualLoginHint CONSTANT)

public:
    explicit GreeterWrapper(QObject *parent = nullptr);

    QString lastLoggedInUser() const;
    QString lastLoggedInSession() const;
    QString guestLoginName() const;

Q_SIGNALS:
    void aboutToLogin();

public Q_SLOTS:
    bool startSessionSync(const QString &session = QString());

protected:
    bool eventFilter(QObject *obj, QEvent *event) override;

private:
    void saveLastUserAndSession(const QString &user, const QString &session);
    KSharedConfig::Ptr m_config;
    bool m_allowAutologin = true;
};

#endif // GREETERWRAPPER_H
